pub enum MemmapMode {
ReadOnly,
ReadWrite,
CopyOnWrite,
}Expand description
Mode for memory-mapped file access.
Variants
ReadOnly
Read-only memory mapping. The file is opened for reading and the resulting slice is immutable.
ReadWrite
Read-write memory mapping. Modifications are written back to the underlying file.
CopyOnWrite
Copy-on-write memory mapping. Modifications are kept in memory and are not written back to the file.