pub struct MemmapArray<T: Element> { /* private fields */ }Expand description
A read-only memory-mapped array backed by a .npy file.
The array data is mapped directly from the file. No copy is made. The data remains valid as long as this struct is alive.
Implementations
Sourceimpl<T: Element> MemmapArray<T>
impl<T: Element> MemmapArray<T>
Sourcepub fn to_array(&self) -> FerrayResult<Array<T, IxDyn>>
pub fn to_array(&self) -> FerrayResult<Array<T, IxDyn>>
Copy the memory-mapped data into an owned Array.